import 'hardhat/types/runtime';
import 'hardhat/types/config';
import type { BigNumber } from '@ethersproject/bignumber';
import { ExtendedArtifact } from './types';
import { Artifact } from 'hardhat/types';
declare module 'hardhat/types/config' {
    interface HardhatUserConfig {
        namedAccounts?: {
            [name: string]: string | number | {
                [network: string]: null | number | string;
            };
        };
        external?: {
            deployments?: {
                [networkName: string]: string[];
            };
            artifacts?: string[];
            deploy?: string[];
        };
    }
    interface HardhatConfig {
        namedAccounts: {
            [name: string]: string | number | {
                [network: string]: null | number | string;
            };
        };
        external?: {
            deployments?: {
                [networkName: string]: string[];
            };
            artifacts?: string[];
            deploy?: string[];
        };
    }
    interface HardhatNetworkUserConfig {
        live?: boolean;
        saveDeployments?: boolean;
        tags?: string[];
    }
    interface HttpNetworkUserConfig {
        live?: boolean;
        saveDeployments?: boolean;
        tags?: string[];
    }
    interface ProjectPathsUserConfig {
        deploy?: string;
        deployments?: string;
        imports?: string;
    }
    interface HardhatNetworkConfig {
        live: boolean;
        saveDeployments: boolean;
        tags: string[];
    }
    interface HttpNetworkConfig {
        live: boolean;
        saveDeployments: boolean;
        tags: string[];
    }
    interface ProjectPathsConfig {
        deploy: string;
        deployments: string;
        imports: string;
    }
}
declare module 'hardhat/types/runtime' {
    interface HardhatRuntimeEnvironment {
        deployments: DeploymentsExtension;
        getNamedAccounts: () => Promise<{
            [name: string]: Address;
        }>;
        getUnnamedAccounts: () => Promise<string[]>;
        getChainId(): Promise<string>;
    }
    interface Network {
        live: boolean;
        saveDeployments: boolean;
        tags: Record<string, boolean>;
    }
    interface DeployFunction {
        (env: HardhatRuntimeEnvironment): Promise<void | boolean>;
        skip?: (env: HardhatRuntimeEnvironment) => Promise<boolean>;
        tags?: string[];
        dependencies?: string[];
        runAtTheEnd?: boolean;
        id?: string;
    }
    type Address = string;
    type ABI = any[];
    type Log = {
        blockNumber: number;
        blockHash: string;
        transactionHash: string;
        transactionIndex: number;
        logIndex: number;
        removed: boolean;
        address: string;
        topics: string[];
        data: string;
    };
    type Receipt = {
        from: Address;
        transactionHash: string;
        blockHash: string;
        blockNumber: number;
        transactionIndex: number;
        cumulativeGasUsed: BigNumber | string | number;
        gasUsed: BigNumber | string | number;
        contractAddress?: string;
        to?: Address;
        logs?: Log[];
        events?: any[];
        logsBloom?: string;
        byzantium?: boolean;
        status?: number;
        confirmations?: number;
    };
    type DiamondFacets = Array<string>;
    interface DiamondOptions extends TxOptions {
        owner?: Address;
        facets: DiamondFacets;
        log?: boolean;
        libraries?: Libraries;
        linkedData?: any;
        upgradeIndex?: number;
        execute?: {
            methodName: string;
            args: any[];
        };
        deterministicSalt?: string;
    }
    interface ProxyOptions {
        owner?: Address;
        upgradeIndex?: number;
        methodName?: string;
    }
    interface DeployOptionsBase extends TxOptions {
        contract?: string | {
            abi: ABI;
            bytecode: string;
            deployedBytecode?: string;
            metadata?: string;
            methodIdentifiers?: any;
            storageLayout?: any;
            userdoc?: any;
            devdoc?: any;
            gasEstimates?: any;
        };
        args?: any[];
        fieldsToCompare?: string | string[];
        skipIfAlreadyDeployed?: boolean;
        linkedData?: any;
        libraries?: Libraries;
        proxy?: boolean | string | ProxyOptions;
    }
    interface DeployOptions extends DeployOptionsBase {
        deterministicDeployment?: boolean | string;
    }
    interface Create2DeployOptions extends DeployOptionsBase {
        salt?: string;
    }
    interface CallOptions {
        from?: string;
        gasLimit?: string | number | BigNumber;
        gasPrice?: string | BigNumber;
        value?: string | BigNumber;
        nonce?: string | number | BigNumber;
        to?: string;
        data?: string;
    }
    interface TxOptions extends CallOptions {
        from: string;
        log?: boolean;
        dev_forceMine?: boolean;
        estimatedGasLimit?: string | number | BigNumber;
        estimateGasExtra?: string | number | BigNumber;
    }
    interface Execute extends TxOptions {
        name: string;
        methodName: string;
        args?: any[];
    }
    interface SimpleTx extends TxOptions {
        to: string;
    }
    interface DeployedContract {
        address: Address;
        abi: ABI;
    }
    interface DeployResult extends Deployment {
        newlyDeployed: boolean;
    }
    type Json = null | boolean | number | string | Json[] | {
        [prop: string]: Json;
    };
    type JsonCompatible<T> = {
        [P in keyof T]: T[P] extends Json ? T[P] : Pick<T, P> extends Required<Pick<T, P>> ? never : T[P] extends (() => any) | undefined ? never : JsonCompatible<T[P]>;
    };
    type FixtureFunc = (env: HardhatRuntimeEnvironment, options?: Json) => Promise<any>;
    interface DeploymentsExtension {
        deploy(name: string, options: DeployOptions): Promise<DeployResult>;
        diamond: {
            deploy(name: string, options: DiamondOptions): Promise<DeployResult>;
        };
        deterministic(name: string, options: Create2DeployOptions): Promise<{
            address: Address;
            deploy(): Promise<DeployResult>;
        }>;
        fetchIfDifferent(name: string, options: DeployOptions): Promise<{
            differences: boolean;
            address?: string;
        }>;
        save(name: string, deployment: DeploymentSubmission): Promise<void>;
        get(name: string): Promise<Deployment>;
        getOrNull(name: string): Promise<Deployment | null>;
        getDeploymentsFromAddress(address: string): Promise<Deployment[]>;
        all(): Promise<{
            [name: string]: Deployment;
        }>;
        getExtendedArtifact(name: string): Promise<ExtendedArtifact>;
        getArtifact(name: string): Promise<Artifact>;
        run(tags?: string | string[], options?: {
            resetMemory?: boolean;
            deletePreviousDeployments?: boolean;
            writeDeploymentsToFiles?: boolean;
            export?: string;
            exportAll?: string;
        }): Promise<{
            [name: string]: Deployment;
        }>;
        fixture(tags?: string | string[], options?: {
            fallbackToGlobal: boolean;
        }): Promise<{
            [name: string]: Deployment;
        }>;
        createFixture(func: FixtureFunc, id?: string): () => Promise<any>;
        log(...args: any[]): void;
        execute(name: string, options: TxOptions, methodName: string, ...args: any[]): Promise<Receipt>;
        rawTx(tx: SimpleTx): Promise<Receipt>;
        catchUnknownSigner(action: Promise<any> | (() => Promise<any>)): Promise<void>;
        read(name: string, options: CallOptions, methodName: string, ...args: any[]): Promise<any>;
        read(name: string, methodName: string, ...args: any[]): Promise<any>;
    }
    interface ContractExport {
        address: string;
        abi: any[];
        linkedData?: any;
    }
    interface Export {
        chainId: string;
        name: string;
        contracts: {
            [name: string]: ContractExport;
        };
    }
    type MultiExport = {
        [chainId: string]: {
            [name: string]: Export;
        };
    };
    type Libraries = {
        [libraryName: string]: Address;
    };
    interface FacetCut {
        facetAddress: string;
        functionSelectors: string[];
    }
    interface DeploymentSubmission {
        abi: ABI;
        address: Address;
        receipt?: Receipt;
        transactionHash?: string;
        history?: Deployment[];
        args?: any[];
        linkedData?: any;
        solcInput?: string;
        solcInputHash?: string;
        metadata?: string;
        bytecode?: string;
        deployedBytecode?: string;
        userdoc?: any;
        devdoc?: any;
        methodIdentifiers?: any;
        diamondCut?: FacetCut[];
        facets?: FacetCut[];
        execute?: {
            methodName: string;
            args: any[];
        };
        storageLayout?: any;
        libraries?: Libraries;
        gasEstimates?: any;
    }
    interface Deployment {
        abi: ABI;
        address: Address;
        receipt?: Receipt;
        transactionHash?: string;
        history?: Deployment[];
        args?: any[];
        linkedData?: any;
        solcInputHash?: string;
        metadata?: string;
        bytecode?: string;
        deployedBytecode?: string;
        libraries?: Libraries;
        userdoc?: any;
        devdoc?: any;
        methodIdentifiers?: any;
        diamondCut?: FacetCut[];
        facets?: FacetCut[];
        storageLayout?: any;
        gasEstimates?: any;
    }
}
//# sourceMappingURL=type-extensions.d.ts.map